# Nyckel

Python package for <www.nyckel.com>

![build](https://github.com/NyckelAI/python-sdk/actions/workflows/build.yml/badge.svg)
![test](https://github.com/NyckelAI/python-sdk/actions/workflows/test.yml/badge.svg)

## Local development

* Run Nyckel Server and Trainer instances locally
* pytest -s
